/*
 * Copyright (c) 1999, 2000  Motoyuki Kasahara.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions, and the following disclaimer,
 *    without modification, immediately at the beginning of the file.
 * 2. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef PCCARD_H
#define PCCARD_H

#include <pccard_low.h>
#include <pccard_alias.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Maximum length of manufacturer string.
 */
#define PCCARD_MAX_MANUFACTURER_LENGTH 127

/*
 * Maximum length of version string.
 */
#define PCCARD_MAX_VERSION_LENGTH      31

/*
 * Maximum length of driver name.
 */
#define PCCARD_MAX_DRIVER_LENGTH       15

/*
 * Additional card status.
 */
#define PCCARD_STATUS_FILLED2          10
#define PCCARD_STATUS_INACTIVE2        11

/*
 * Function declarations.
 */
#if defined(__STDC__) || defined(__cplusplus)
int pccard_initialize_client(const char *);
int pccard_synchronize(void);
void pccard_finalize_client(void);
const char *pccard_alias_file_name(void);
int pccard_number_of_slots(void);
const char *pccard_manufacturer(int);
const char *pccard_version(int);
const char *pccard_driver(int);
int pccard_status(int);
const char *pccard_alias(int);
int pccard_insert(int);
int pccard_remove(int);
int pccard_update(void);
#else /* not defined(__STDC__) && not defined(__cplusplus) */
int pccard_initalize_client();
int pccard_synchronize();
void pccard_finialize_client();
int pccard_number_of_slots();
const char *pccard_manufacturer();
const char *pccard_version();
const char *pccard_driver();
int pccard_status();
const char *pccard_alias();
int pccard_alias();
int pccard_insert();
int pccard_remove();
int pccard_update();
#endif /* not defined(__STDC__) && not defined(__cplusplus) */

#ifdef __cplusplus
}
#endif

#endif /* not PCCARD_H */
