/*
 * Copyright (c) 1999, 2000  Motoyuki Kasahara.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions, and the following disclaimer,
 *    without modification, immediately at the beginning of the file.
 * 2. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <errno.h>
#include <stdarg.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/un.h>
#include <unistd.h>
#include <sys/time.h>

#include "pccard_error.h"

/*
 * Message handlers.
 */
void (*pccard_output_error_message)(const char *, ...)
    = pccard_message_to_stderr;
void (*pccard_output_warning_message)(const char *, ...)
    = pccard_message_to_stderr;
void (*pccard_output_debug_message)(const char *, ...)
    = pccard_message_to_stderr;

/*
 * Debug flag.
 */
int pccard_debug_flag = 0;


/*
 * Default error message handler.
 * Output an error message to stderr.
 */
void
pccard_message_to_stderr(const char *format, ...)
{
    va_list ap;

    va_start(ap, format);
    vfprintf(stderr, format, ap);
    fputc('\n', stderr);
    va_end(ap);
}


/*
 * Another Error message handler.
 * Output an error message to nowhere.
 */
void
pccard_message_to_nowhere(const char *format, ...)
{
}


/*
 * Set error message handler.
 */
void 
pccard_set_error_message_handler(void (*function)(const char *format, ...))
{
    pccard_output_error_message = function;
}


/*
 * Set warning message handler.
 */
void
pccard_set_warning_message_handler(void (*function)(const char *format, ...))
{
    pccard_output_warning_message = function;
}


/*
 * Set debug message handler.
 */
void
pccard_set_debug_message_handler(void (*function)(const char *format, ...))
{
    pccard_output_warning_message = function;
}


/*
 * Set error message handler.
 */
void (*
pccard_error_message_handler(void))(const char *format, ...)
{
    return pccard_output_error_message;
}


/*
 * Set warning message handler.
 */
void (*
pccard_warning_message_handler(void))(const char *format, ...)
{
    return pccard_output_warning_message;
}


/*
 * Set debug message handler.
 */
void (*
pccard_debug_message_handler(void))(const char *format, ...)
{
    return pccard_output_debug_message;
}


/*
 * Set debug flag.
 */
void 
pccard_set_debug_flag(void)
{
    pccard_debug_flag = 1;
}


/*
 * Unset debug flag.
 */
void 
pccard_unset_debug_flag(void)
{
    pccard_debug_flag = 0;
}


